#ifndef __NETFLOW_AUDIT_DROP_H
#define __NETFLOW_AUDIT_DROP_H

#include <unistd.h>

#include "base_types.h"

/* 
 * description		: 添加基于进程或五元组的网络流量审计策略
 * @param - policy	: 审计策略
 */
int netflow_audit_add_policy(struct netflow_audit_policy * policy);

/* 
 * description		: 删除（单条）网络流量审计策略
 * @param - policy	: 审计策略id
 */
int netflow_audit_delete_policy(uint16_t policy_id);

/* 
 * description		: 清除所有网络流量审计策略
 */
int netflow_audit_clear_policy(void);

/* 
 * description		: 查询网络流量审计所有策略
 * @param - count	: 审计策略数量
 */
struct netflow_audit_policy * netflow_audit_policies(int *count);


/* 
 * description		: 获取进程流量数据信息的socket句柄的接口
 */
int netflow_audit_socket_open(void);


/* 
 * description		    : 接收进程流量数据信息接口
  * @param - socket_fd	: socket句柄
  * @param - buffer     : 用来接收数据包的缓冲
  * @param - length     : 缓冲区大小
 */
size_t netflow_audit_socket_recv(int socket_fd, void *buffer, size_t length);


/* 
 * description		: 关闭进程流量数据信息句柄接口
 */
int netflow_audit_socket_close(int socket_fd);


/* 
 * description		: 添加网络数据阻断策略
 * @param - policy	: 阻断策略
 */
int netflow_drop_add_policy(struct netflow_drop_policy * policy );


/* 
 * description		: 删除网络数据阻断策略
 * @param - policy	: 阻断策略id
 */
int netflow_drop_delete_policy(uint16_t policy_id);


/* 
 * description		: 清空网络数据阻断策略
 */
int netflow_drop_clear_policy();


/* 
 * description		: 获取所有网络流量阻断策略
 * @param - count	: 网络流量阻断策略数量
 */
struct netflow_drop_policy * netflow_drop_policies(int *count);





/* 
 * description		: 获取日志阻断策略数据流的socket句柄的接口
 */
int netflow_drop_log_open();




/* 
 * description		    : 接收进程阻断流量数据信息接口
  * @param - socket_fd	: socket_fd句柄
  * @param - buffer     : 用来接收数据包的缓冲
  * @param - length     : 缓冲区大小
 */
int netflow_drop_log_recv(int socket_fd,void * buffer,size_t length);


/* 
 * description		    : 关闭进程阻断流量数据信息句柄接口
 * @param -socket_fd    : socket_fd句柄
 */
int netflow_drop_log_close(int socket_fd);



#endif